api.cases.v2.test_helpers.servicesubscription package — Argus-Toolbelt 1.0 documentation

# api.cases.v2.test_helpers.servicesubscription package

## Submodules

## api.cases.v2.test_helpers.servicesubscription.add_customer_service_subscription module

`api.cases.v2.test_helpers.servicesubscription.add_customer_service_subscription.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/servicesubscription, respond with HTTP 403

`api.cases.v2.test_helpers.servicesubscription.add_customer_service_subscription.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/servicesubscription, respond with HTTP 404

`api.cases.v2.test_helpers.servicesubscription.add_customer_service_subscription.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/servicesubscription, respond with HTTP 200

`api.cases.v2.test_helpers.servicesubscription.add_customer_service_subscription.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/servicesubscription, respond with HTTP 401

## api.cases.v2.test_helpers.servicesubscription.delete_customer_service_subscription module

`api.cases.v2.test_helpers.servicesubscription.delete_customer_service_subscription.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/servicesubscription/w+, respond with HTTP 403

`api.cases.v2.test_helpers.servicesubscription.delete_customer_service_subscription.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/servicesubscription/w+, respond with HTTP 404

`api.cases.v2.test_helpers.servicesubscription.delete_customer_service_subscription.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/servicesubscription/w+, respond with HTTP 200

`api.cases.v2.test_helpers.servicesubscription.delete_customer_service_subscription.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/servicesubscription/w+, respond with HTTP 401

## api.cases.v2.test_helpers.servicesubscription.list_subscriptions module

`api.cases.v2.test_helpers.servicesubscription.list_subscriptions.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/servicesubscription, respond with HTTP 403

`api.cases.v2.test_helpers.servicesubscription.list_subscriptions.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/servicesubscription, respond with HTTP 404

`api.cases.v2.test_helpers.servicesubscription.list_subscriptions.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/servicesubscription, respond with HTTP 200

`api.cases.v2.test_helpers.servicesubscription.list_subscriptions.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v2/servicesubscription, respond with HTTP 401

## Module contents